@@ -1,7 +1,7 @@
 ---------------------------------------------------------------------------
 -- @author Julien Danjou &lt;julien@danjou.info&gt;
 -- @copyright 2008 Julien Danjou
--- @release v3.4.6
+-- @release v3.4.9
 ---------------------------------------------------------------------------
 
 -- Grab environment we need
@@ -113,7 +113,8 @@ end
 function focus.filter(c)
     if c.type == "desktop"
         or c.type == "dock"
-        or c.type == "splash" then
+        or c.type == "splash"
+        or not c.focusable then
         return nil
     end
     return c
@@ -669,7 +670,7 @@ end
 -- @return col the column number
 -- @return idx index of the client in the column
 -- @return num the number of visible clients in the column
-local function idx(c)
+function idx(c)
     local c = c or capi.client.focus
     if not c then return end
 
@@ -723,8 +724,8 @@ end
 -- @param c the client
 function setwfact(wfact, c)
     -- get the currently selected window
-    local c =  c or capi.client.focus
-    if not c then return end
+    local c = c or capi.client.focus
+    if not c or not c:isvisible() then return end
 
     local t = tag.selected(c.screen)
     local w = idx(c)
