@@ -1,7 +1,7 @@
 ---------------------------------------------------------------------------
 -- @author Julien Danjou &lt;julien@danjou.info&gt;
 -- @copyright 2008 Julien Danjou
--- @release v3.4.6
+-- @release v3.4.9
 ---------------------------------------------------------------------------
 
 -- Grab environment we need
@@ -56,14 +56,8 @@ end
 --- Add a tag.
 -- @param name The tag name, a string
 -- @param props The tags properties, a table
--- @return The created tag or nil if not created.
--- If the name is a valid string then the tag will be created and each key,value
--- pair in 'props' table is iterated and applied to the tag. If the 'name'
--- argument is nil or its string length is zero then the function returns nil.
+-- @return The created tag
 function add(name, props)
-    -- abort if the name is not provided
-    if not name or #(tostring(name)) == 0 then return end
-
     local properties = props or {}
     local newtag = capi.tag{name = name}
     newtag.screen = properties.screen or capi.mouse.screen
@@ -96,25 +90,110 @@ function new(names, screen, layout)
     return tags
 end
 
+--- Find a suitable fallback tag.
+-- @param screen The screen number to look for a tag on. [mouse.screen]
+-- @param target A table of tags we consider unacceptable. [selectedlist(scr)]
+function find_fallback(screen, invalids)
+    local scr = screen or capi.mouse.screen
+    local t = invalids or selectedlist(scr)
+
+    for _, v in pairs(capi.screen[scr]:tags()) do
+        if not util.table.hasitem(t, v) then return v end
+    end
+end
+
+--- Delete a tag.
+-- @param target_tag Optional tag object to delete. [selected()]
+-- @param fallback_tag Tag to assign stickied tags to. [~selected()]
+-- @return Returns true if the tag is successfully deleted, nil otherwise.
+-- If there are no clients exclusively on this tag then delete it. Any
+-- stickied clients are assigned to the optional 'fallback_tag'.
+-- If after deleting the tag there is no selected tag, try and restore from
+-- history or select the first tag on the screen.
+function delete(target_tag, fallback_tag)
+    -- abort if no tag is passed or currently selected
+    local target_tag = target_tag or selected()
+    if target_tag == nil then return end
+
+    local ntags = #capi.screen[target_tag.screen]:tags()
+    local target_scr = target_tag.screen
+
+    -- We can't use the target tag as a fallback.
+    local fallback_tag = fallback_tag
+    if fallback_tag == target_tag then return end
+
+    -- No fallback_tag provided, try and get one.
+    if fallback_tag == nil then
+        fallback_tag = find_fallback(target_scr, {target_tag})
+    end
+
+    -- Abort if we would have un-tagged clients.
+    local clients = target_tag:clients()
+    if ( #clients > 0 and ntags <= 1 ) or fallback_tag == nil then return end
+
+    -- Move the clients we can off of this tag.
+    for _, c in pairs(clients) do
+
+        -- If a client has only this tag, or stickied clients with
+        -- nowhere to go, abort.
+        if (not c.sticky and #c:tags() == 1) or
+                                    (c.sticky and fallback_tag == nil) then
+            return
+        else
+            c:tags({fallback_tag})
+        end
+    end
+
+    -- delete the tag
+    target_tag.screen = nil
+
+    -- If no tags are visible, try and view one.
+    if selected(target_scr) == nil and ntags > 0 then
+        history.restore()
+        if selected(target_scr) == nil then
+            capi.screen[target_scr]:tags()[1].selected = true
+        end
+    end
+
+    return true
+end
+
 --- Update the tag history.
 -- @param obj Screen object.
 function history.update(obj)
     local s = obj.index
-    local curtags = capi.screen[s]:tags()
+    local curtags = selectedlist(s)
     -- create history table
     if not data.history[s] then
         data.history[s] = {}
-    -- limit history
-    elseif #data.history[s] >= history.limit then
-        for i = history.limit, #data.history[s] do
-            data.history[s][i] = nil
+    else
+        if data.history[s].current then
+            -- Check that the list is not identical
+            local identical = true
+            for idx, tag in ipairs(data.history[s].current) do
+                if curtags[idx] ~= tag then
+                    identical = false
+                    break
+                end
+            end
+
+            -- Do not update history the table are identical
+            if identical then return end
+        end
+
+        -- Limit history
+        if #data.history[s] >= history.limit then
+            for i = history.limit, #data.history[s] do
+                data.history[s][i] = nil
+            end
         end
     end
+
     -- store previously selected tags in the history table
     table.insert(data.history[s], 1, data.history[s].current)
     data.history[s].previous = data.history[s][1]
     -- store currently selected tags
-    data.history[s].current = setmetatable(selectedlist(s), { __mode = 'v' })
+    data.history[s].current = setmetatable(curtags, { __mode = 'v' })
 end
 
 --- Revert tag history.
