@@ -1,7 +1,7 @@
 ---------------------------------------------------------------------------
 -- @author Julien Danjou &lt;julien@danjou.info&gt;
 -- @copyright 2008 Julien Danjou
--- @release v3.4.6
+-- @release v3.4.9
 ---------------------------------------------------------------------------
 
 -- Grab environment we need
@@ -253,8 +253,7 @@ local function button_group(name, attrs, sfn, ...)
     s.attributes = attrs
     s.states = {}
 
-    for i = 1, #arg do
-        local state = arg[i]
+    for i, state in pairs({...}) do
         s.states[state.idx] = state
     end
 
