@@ -1,7 +1,7 @@
 ----------------------------------------------------------------------------
 -- @author koniu &lt;gkusnierz@gmail.com&gt;
 -- @copyright 2008 koniu
--- @release v3.4.6
+-- @release v3.4.9
 ----------------------------------------------------------------------------
 
 -- Package environment
@@ -9,6 +9,7 @@ local pairs = pairs
 local table = table
 local type = type
 local string = string
+local pcall = pcall
 local capi = { screen = screen,
                awesome = awesome,
                dbus = dbus,
@@ -297,7 +298,7 @@ function notify(args)
 
     -- replace notification if needed
     if args.replaces_id then
-        obj = getById(args.replaces_id)
+        local obj = getById(args.replaces_id)
         if obj then
             -- destroy this and ...
             destroy(obj)
@@ -354,9 +355,21 @@ function notify(args)
     local textbox = capi.widget({ type = "textbox", align = "flex" })
     textbox:buttons(util.table.join(button({ }, 1, run), button({ }, 3, die)))
     layout.margins[textbox] = { right = margin, left = margin, bottom = margin, top = margin }
-    textbox.text = string.format('<span font_desc="%s"><b>%s</b>%s</span>', font, title, text:gsub("<br.->", "\n"))
     textbox.valign = "middle"
 
+    local function setText(pattern, replacements)
+        textbox.text = string.format('<span font_desc="%s"><b>%s</b>%s</span>', font, title, text:gsub(pattern, replacements))
+    end
+
+    -- First try to set the text while only interpreting <br>.
+    -- (Setting a textbox' .text to an invalid pattern throws a lua error)
+    if not pcall(setText, "<br.->", "\n") then
+        -- That failed, escape everything which might cause an error from pango
+        if not pcall(setText, "[<>&]", { ['<'] = "&lt;", ['>'] = "&gt;", ['&'] = "&amp;" }) then
+            textbox.text = "<i>&lt;Invalid markup, cannot display message&gt;</i>"
+        end
+    end
+
     -- create iconbox
     local iconbox = nil
     if icon then
@@ -480,7 +493,8 @@ if capi.dbus then
             args.preset.callback(data, appname, replaces_id, icon, title, text, actions, hints, expire)) then
             if icon ~= "" then
                 args.icon = icon
-            elseif hints.icon_data then
+            elseif hints.icon_data or hints.image_data then
+                if hints.icon_data == nil then hints.icon_data = hints.image_data end
                 -- icon_data is an array:
                 -- 1 -> width, 2 -> height, 3 -> rowstride, 4 -> has alpha
                 -- 5 -> bits per sample, 6 -> channels, 7 -> data
